#!/bin/bash

# This is the Young et al. (In Prep) modified rotation file. To make it comparable to the Matthews et al. (2016) modified file, I removed the true polar wander and the longitudinal shift. I then also implanted the Torsvik et al. (2012) paleomag reference frame for 0 to 230 Ma, and also implemented the Domeier and Torsvik (2014) pure paleomagnetic reference frame for all earlier times. That’s why both models are referred to as being “modified”.

#This script take geometries exported as .gmt files from GPlates, clips the geometries to within a 5 degree humid band and then calculates the area within the humid band. 
#The folder structure is provided with three time steps of .gmt files provided. For information on how to export geometries from gplates, see the user manual at https://www.gplates.org/

rm /Output/Continental/Clipped_5_LIP_Area.dat 


# These are the input files 
rot_file=Input/Matthews_etal_GPC_2016_410-0Ma_GK07_PaleomagneticReferenceFrame.rot
coastline_gpml=Input/Global_coastlines_2016_v3_low_res.gpml
LIPs_gpml=Input/EarthByte_LIPs_20170131.gpml
LIPs_Continental_gpml=Input/EarthByte_LIPs_Continental_20170131

age=0
max_age=3



while (( ${age} <= ${max_age} ))
do
	

	#This is for all the Continental LIPs


	LIPs_reconstructed=ReconstructedData/Continental/LIPs_G_M_T_files/reconstructed_continental_${age}.00Ma.gmt
	# python27 reconstruct_feature.py -r ${rot_file} -m ${coastline_gpml} -t ${age} -e gmt -- test_""

	
	#Makes a file with the total area of LIPs in +/-5 degrees at each age
	
	gmt gmtspatial -C -R-180/180/-5/5 ${LIPs_reconstructed} > ReconstructedData/Continental/Clipped_LIPs5_G_M_T_files/clipped_reconstructed__${age}.gmt

	LIPs_reconstructed_clipped5=ReconstructedData/Continental/Clipped_LIPs5_G_M_T_files/clipped_reconstructed__${age}.gmt

	gmt gmtspatial ${LIPs_reconstructed_clipped5} -Qk > ReconstructedData/Continental/Clipped_LIPs5_D_A_T_files/Clipped_LIPs_${age}.dat

	area_clipped_5=$( awk 'BEGIN {FS = "\t"} ; {sum+=$3} END {print sum}' ReconstructedData/Continental/Clipped_LIPs5_D_A_T_files/Clipped_LIPs_${age}.dat )

	echo " Area of the LIPs within +/-5 degrees is ${area_clipped_5} at ${age} Ma"

	echo ${age} ${area_clipped_5} >> Output/Continental/Clipped_5_LIP_Area.dat




age=$(($age + 1 ))
done









